helga
=====

.. image:: https://img.shields.io/travis/shaunduncan/helga/master.svg
    :target: https://travis-ci.org/shaunduncan/helga

.. image:: https://img.shields.io/coveralls/shaunduncan/helga/master.svg
    :target: https://coveralls.io/r/shaunduncan/helga?branch=master

.. image:: https://img.shields.io/pypi/v/helga.svg
    :target: https://pypi.python.org/pypi/helga

.. image:: https://img.shields.io/pypi/dm/helga.svg
    :target: https://pypi.python.org/pypi/helga


About
-----
Helga is a full-featured IRC bot for Python 2.6/2.7 using `Twisted`_. Helga originally started
as a python fork of a perl-based IRC bot `olga`_, but has grown considerably since then.
Full documentation can be found at http://helga.readthedocs.org.


Contributing
------------
Contributions are **always** welcomed, whether they be in the form of bug fixes, enhancements,
or just bug reports. To report any issues, please create a ticket on `github`_. For code
changes, please note that any pull request will be denied a merge if the test suite fails.


License
-------
Copyright (c) 2014 Shaun Duncan

Helga is open source software, dual licensed under the `MIT`_ and `GPL`_ licenses. Dual licensing
was chosen for this project so that plugin authors can create plugins under their choice
of license that is compatible with this project.

.. _`GPL`: https://github.com/shaunduncan/helga/blob/master/LICENSE-GPL
.. _`MIT`: https://github.com/shaunduncan/helga/blob/master/LICENSE-MIT
.. _`Twisted`: https://twistedmatrix.com/trac/
.. _`olga`: https://github.com/thepeopleseason/olga
.. _`github`: https://github.com/shaunduncan/helga/issues
